# SGA

SGA is a daemon for executing and monitoring CSBase jobs. This implementation
is made of the following components:

## sga-daemon

The core SGA daemon. To use it, you will also need a driver.

## sga-driver-posix

A SGA daemon driver for running jobs locally on POSIX operating systems.
Tested on Linux and Cygwin.

## sga-driver-pbs

A SGA daemon driver for running jobs on Torque PBS clusters. This driver
is written using `sga-exec`, so it can run either locally (at the cluster
master machine) or manage the cluster remotely over SSH.

## sga-exec

An extensible library for abstracting local and remote execution of commands,
to be used by SGA drivers.

To enable SSH tunnelling in your `sga.exec`-powered SGA driver, add the
following to your `sgad.cfg`:

    driver_config = {
       exec_driver = "sga.exec.ssh",
       exec_config = {
          host = "username@hostname",
          port = 22,
       }
    }

To use `sga-exec` when writing your own driver, the rule of thumb is to
avoid Lua's standard `io.*` and `os.*` routines.

## Install

Clone the git repository

```shell
git clone https://git.tecgraf.puc-rio.br/csbase/sgarest-daemon
cd sgarest-daemon
```

Install Luarocks 2.4.2 then run the following commands to install the POSIX driver and the PBS driver respectively:

POSIX

```shell
luarocks install lua-schema-scm-1.rockspec
luarocks make sga-daemon-scm-1.rockspec
luarocks make sga-driver-posix-scm-1.rockspec
```

PBS (experimental)

```shell
luarocks install lua-schema-scm-1.rockspec
luarocks make sga-daemon-scm-1.rockspec
luarocks make sga-exec-scm-1.rockspec
luarocks make sga-driver-pbs-scm-1.rockspec
```

To install locally for the current user, use the option `--local` in the commands above.

## Docker

### Build

```shell
docker build . -t csbase/sgarest-daemon:1.1.1 --build-arg SGAREST_VERSION=1.1.1
```

### Run

```shell
docker run --rm \
-p 40100:40100 \
-v /home/sgad/logs/sga:/sgad/logs \
-v /home/sgad/projects:/sgad/projects \
-v /home/sgad/algorithms:/sgad/algorithms \
-e CSBASE_SERVER="http://csgrid:40500" \
-e SGAD_HOST="sgad40100" \
-e SGAD_PORT="40100" \
-e SGAD_NAME="40100" \
--network host \
csbase/sgarest-daemon:1.1.1
```

## Credits

This next-generation SGA was designed and implemented at LabLua, PUC-Rio by
Hisham Muhammad <hisham@gobolinux.org> and Ana Lúcia de Moura
<amoura@inf.puc-rio.br>.

